************************************************
Manual
************************************************

The following sections describes the underlying structure of ANNarchy and how to use its principal functions. The section :doc:`API` present in detail each available class and its methods. The section :doc:`Example` describes how to use these functions on particular examples.

.. toctree::
    :maxdepth: 2

    manual/Structure.rst
    manual/Parser.rst
    manual/RateNeuron.rst
    manual/SpikeNeuron.rst
    manual/RateSynapse.rst
    manual/SpikeSynapse.rst
    manual/Populations.rst
    manual/Projections.rst
    manual/Connector.rst
    manual/Inputs.rst
    manual/Simulation.rst
    manual/Configuration.rst
    manual/NumericalMethods.rst
    manual/Recording.rst
    manual/Saving.rst
    manual/Network.rst
    manual/Hybrid.rst
    manual/StructuralPlasticity.rst
    manual/ConvolutionalNetworks.rst
    manual/Notebooks.ipynb
    manual/Reporting.rst
    manual/Logging.ipynb